@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use XSLoader;
 use Scope::Guard;
@@ -69,6 +69,10 @@ previous %^H afterwards. Thus it can be thought of a lexically-scoped backport o
 
 Note that C<lexicalize_hh> also sets the $^H bit that "localizes" (or in this case "lexicalizes") %^H.
 
+=head1 VERSION
+
+0.03
+
 =head1 SEE ALSO
 
 =over
